System

Struct System 

pub struct System { /* private fields */ }

Implementations

Source

impl System

pub fn new() -> System

pub fn bounds(&self) -> &SystemBounds

pub fn is_empty(&self) -> bool

pub fn add( &mut self, new_equation: Equation, field: Option<&PrimitivePolynomialField>, ) -> Result<(Option<Equation>, Vec<SymbolID>), SystemError>

adds eq to the system without error, a tuple (removed_eq, decoded_symbol_ids) is returned. removed_eq is an equation that has been removed from the system if it was already occupying new_equation’s pivot position. decoded_symbol_ids are the ids of all the newly decoded equations if they exist

pub fn take( &mut self, id: SymbolID, field: Option<&PrimitivePolynomialField>, ) -> Option<Vec<u8>>

pub fn drop_id(&mut self, id: SymbolID)

removes all the equations whose coef for the given id is not zero this is useful if we decide to not recover a specific ID, then we just drop the equations that need this id to be solved

pub fn saturate_sub_ids(&mut self, n: SymbolID)

subtracts the ids such that the pivot ID becomes pivot - n

pub fn clear(&mut self)

pub fn print(&self)