pub struct System { /* private fields */ }Implementations
Sourceimpl System
impl System
pub fn new() -> System
pub fn bounds(&self) -> &SystemBounds
pub fn is_empty(&self) -> bool
Sourcepub fn add(
&mut self,
new_equation: Equation,
field: Option<&PrimitivePolynomialField>,
) -> Result<(Option<Equation>, Vec<SymbolID>), SystemError>
pub fn add( &mut self, new_equation: Equation, field: Option<&PrimitivePolynomialField>, ) -> Result<(Option<Equation>, Vec<SymbolID>), SystemError>
adds eq to the system without error, a tuple (removed_eq, decoded_symbol_ids) is returned. removed_eq is an equation that has been removed from the system if it was already occupying new_equation’s pivot position. decoded_symbol_ids are the ids of all the newly decoded equations if they exist
pub fn take( &mut self, id: SymbolID, field: Option<&PrimitivePolynomialField>, ) -> Option<Vec<u8>>
Sourcepub fn drop_id(&mut self, id: SymbolID)
pub fn drop_id(&mut self, id: SymbolID)
removes all the equations whose coef for the given id is not zero this is useful if we decide to not recover a specific ID, then we just drop the equations that need this id to be solved
Sourcepub fn saturate_sub_ids(&mut self, n: SymbolID)
pub fn saturate_sub_ids(&mut self, n: SymbolID)
subtracts the ids such that the pivot ID becomes pivot - n
pub fn clear(&mut self)
pub fn print(&self)